package com.yuexiu.secp.read.controller;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson.JSONObject;
import com.sie.iot.common.bean.PaginationRequestData;
import com.sie.iot.common.bean.RequestData;
import com.sie.iot.common.bean.ResponseData;
import com.sie.iot.common.iotenum.ResponseMsgCode;
import com.sie.iot.common.model.inter.IBaseCommon;
import com.sie.iot.common.secure.annotation.CheckToken;
import com.sie.iot.common.services.CommonAbstractService;
import com.siefw.hibernate.core.paging.Pagination;
import com.yuexiu.secp.read.dto.ArticlePreviewQueryDto;
import com.yuexiu.secp.read.dto.ArticlePreviewSaveDto;
import com.yuexiu.secp.read.dto.CostUnitDto;
import com.yuexiu.secp.read.model.entities.ArticlePreviewEntity;
import com.yuexiu.secp.read.model.entities.CostUnitEntity;
import com.yuexiu.secp.read.model.service.IArticlePreview;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/read/article/preview")
@Api(value = "阅读有礼-预览", tags = "阅读有礼-预览")
public class ArticlePreviewController extends CommonAbstractService {

    @Autowired
    private IArticlePreview iReadService;

    @Override
    public IBaseCommon<?> getBaseCommonServer() {
        return this.iReadService;
    }

    @ApiOperation(value = "分页查询文章任务", notes = "分页文章任务")
    @PostMapping(value = "/findPagination")
    @CheckToken
    public ResponseData<Pagination<ArticlePreviewEntity>> findPagination(@RequestBody PaginationRequestData<ArticlePreviewQueryDto> paginationRequestData) {
        Integer pageIndex = paginationRequestData.getPageIndex();
        Integer pageRows = paginationRequestData.getPageRows();
        ArticlePreviewQueryDto articlePreviewQueryDto = paginationRequestData.getParams();
        JSONObject jsonObject = JSONObject.parseObject(JSONObject.toJSONString(articlePreviewQueryDto));
        Pagination<ArticlePreviewEntity> pagination = iReadService.findPagination(jsonObject, pageIndex, pageRows, paginationRequestData.getOrderByBean());
        return ResponseData.data(pagination);
    }

    @ApiOperation(value = "保存文章任务", notes = "保存文章任务")
    @PostMapping(value = "/save")
    @CheckToken
    public ResponseData<ArticlePreviewEntity> save(@RequestBody RequestData<ArticlePreviewSaveDto> requestData) {
        ArticlePreviewSaveDto articlePreviewDto = requestData.getParams();
        return ResponseData.data(iReadService.saveArticlePreview(articlePreviewDto));
    }

    @ApiOperation(value = "更新文章任务", notes = "更新文章任务")
    @PostMapping(value = "/update")
    @CheckToken
    public ResponseData<ArticlePreviewEntity> update(@RequestBody RequestData<ArticlePreviewSaveDto> requestData) {
        ArticlePreviewSaveDto articlePreviewDto = requestData.getParams();
        ArticlePreviewEntity articlePreviewEntity =
                iReadService.getById(articlePreviewDto.getArticlePreviewId());
        if (null != articlePreviewEntity) {
            return ResponseData.data(iReadService.updateArticlePreview(articlePreviewDto));
        } else {
            return ResponseData.fail(ResponseMsgCode.UPDATE_DATA_NOT_EXIST.msgCode);
        }
    }

    @ApiOperation(value = "根据文章任务id查询相关信息", notes = "根据文章任务id查询相关信息")
    @PostMapping(value = "/findByArticlePreviewId")
    @CheckToken
    public ResponseData<ArticlePreviewSaveDto> findByArticlePreviewId(@RequestParam Long articlePreviewId) {
        ArticlePreviewSaveDto articlePreviewSaveDto = iReadService.findByArticlePreviewId(articlePreviewId);
        return ResponseData.data(articlePreviewSaveDto);
    }

    @ApiOperation(value = "通过Id删除文章任务", notes = "通过Id删除文章任务")
    @GetMapping(value = "/delete")
    @CheckToken
    public ResponseData deleteById(@RequestParam Long id) {
        ArticlePreviewEntity articlePreviewEntity = iReadService.getById(id);
        if (articlePreviewEntity != null) {
            iReadService.deleteById(id);
        }
        return ResponseData.success();
    }

    @ApiOperation(value = "下架", notes = "下架")
    @PostMapping(value = "/off-the-shelves")
//    @CheckToken
    public ResponseData offTheShelves(@RequestParam Long id) {

        return ResponseData.success();
    }

    @ApiOperation(value = "发布", notes = "发布")
    @PostMapping(value = "/release")
//    @CheckToken
    public ResponseData release(@RequestParam Long id) {

        return ResponseData.success();
    }

    @ApiOperation(value = "重新发布", notes = "重新发布")
    @PostMapping(value = "/re-release")
//    @CheckToken
    public ResponseData reRelease(@RequestParam Long id) {

        return ResponseData.success();
    }
}
