package com.yuexiu.secp.read.controller;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson.JSONObject;
import com.sie.iot.common.bean.PaginationRequestData;
import com.sie.iot.common.bean.RequestData;
import com.sie.iot.common.bean.ResponseData;
import com.sie.iot.common.iotenum.ResponseMsgCode;
import com.sie.iot.common.model.inter.IBaseCommon;
import com.sie.iot.common.secure.annotation.CheckToken;
import com.sie.iot.common.services.CommonAbstractService;
import com.siefw.hibernate.core.paging.Pagination;
import com.yuexiu.secp.read.dto.CopywritingDto;
import com.yuexiu.secp.read.model.entities.CopywritingEntity;
import com.yuexiu.secp.read.model.entities.readonly.CopywritingEntityRO;
import com.yuexiu.secp.read.model.service.ICopywriting;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

@Validated
@Api(value = "文案维护", tags = "文案维护")
@RestController
@RequestMapping("/copywritingController")
public class CopywritingController extends CommonAbstractService {

    @Autowired(required = true)
    private ICopywriting copywritingServer;

    @Override
    public IBaseCommon<?> getBaseCommonServer() {
        return this.copywritingServer;
    }

    @ApiOperation(value = "分页查询文案", notes = "分页文案")
    @PostMapping(value = "/findPaginationRO")
    @CheckToken
    public ResponseData<Pagination<CopywritingEntityRO>> findPaginationRO(@RequestBody PaginationRequestData<CopywritingDto> paginationRequestData) {
        Integer pageIndex = paginationRequestData.getPageIndex();
        Integer pageRows = paginationRequestData.getPageRows();
        CopywritingDto copywritingDto = paginationRequestData.getParams();
        JSONObject jsonObject = JSONObject.parseObject(JSONObject.toJSONString(copywritingDto));
        Pagination<CopywritingEntityRO> pagination = copywritingServer.findPaginationRO(jsonObject, pageIndex, pageRows, paginationRequestData.getOrderByBean());
        return ResponseData.data(pagination);
    }

    @ApiOperation(value = "根据id文案信息", notes = "根据id文案信息")
    @GetMapping(value = "/findById")
    @CheckToken
    public ResponseData<CopywritingEntity> findById(Long id) {
        CopywritingEntity copywritingEntity = copywritingServer.getById(id);
        return ResponseData.data(copywritingEntity);
    }

    @ApiOperation(value = "保存文案", notes = "保存文案")
    @PostMapping(value = "/save")
    @CheckToken
    public ResponseData<CopywritingEntity> save(@RequestBody RequestData<CopywritingDto> requestData) {
        CopywritingDto copywritingDto = requestData.getParams();
        CopywritingEntity copywritingEntity = JSONObject.parseObject(JSONObject.toJSONString(copywritingDto), CopywritingEntity.class);
        //固定
        copywritingEntity.setOperatorUserId(getUserSessionBean().getUserId());
        copywritingEntity.setTenantId(getUserSessionBean().getTenantId());

        copywritingServer.save(copywritingEntity);
        return ResponseData.data(copywritingEntity);
    }

    @PostMapping(value = "/update")
    @CheckToken
    public ResponseData<CopywritingEntity> update(@RequestBody RequestData<CopywritingDto> requestData) {
        CopywritingDto copywritingDto = requestData.getParams();
        CopywritingEntity copywritingEntity = copywritingServer.getById(copywritingDto.getCopywritingId());
        if (null != copywritingEntity) {
            BeanUtil.copyProperties(copywritingDto, copywritingEntity);
            //固定
            copywritingEntity.setOperatorUserId(getUserSessionBean().getUserId());
        } else {
            return ResponseData.fail(ResponseMsgCode.UPDATE_DATA_NOT_EXIST.msgCode);
        }
        copywritingServer.update(copywritingEntity);
        return ResponseData.data(copywritingEntity);
    }

    @ApiOperation(value = "通过Id删除文案", notes = "通过Id删除文案")
    @GetMapping(value = "/delete")
    @CheckToken
    public ResponseData deleteById(@RequestParam Long id) {
        CopywritingEntity copywritingEntity = copywritingServer.getById(id);
        if (copywritingEntity != null) {
            copywritingEntity.setDeleteFlag(1);
            copywritingEntity.setOperatorUserId(getUserSessionBean().getUserId());
        }
        copywritingServer.update(copywritingEntity);
        return ResponseData.success();
    }
}
