package com.yuexiu.secp.read.controller;


import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.sie.iot.common.bean.PaginationRequestData;
import com.sie.iot.common.bean.RequestData;
import com.sie.iot.common.bean.ResponseData;
import com.sie.iot.common.iotenum.ResponseMsgCode;
import com.sie.iot.common.model.inter.IBaseCommon;
import com.sie.iot.common.secure.annotation.CheckToken;
import com.sie.iot.common.services.CommonAbstractService;
import com.sie.iot.component.exception.ParameterNotValidException;
import com.siefw.hibernate.core.paging.Pagination;
import com.yuexiu.secp.read.dto.CostUnitDto;
import com.yuexiu.secp.read.model.entities.CostUnitEntity;
import com.yuexiu.secp.read.model.entities.readonly.CostUnitEntityRO;
import com.yuexiu.secp.read.model.service.ICostUnit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

@Validated
@Api(value = "阅读有礼-成本单位", tags = "阅读有礼-成本单位")
@RestController
@RequestMapping("/costUnitController")
public class CostUnitController extends CommonAbstractService {

    @Autowired(required = true)
    private ICostUnit costUnitServer;

    @Override
    public IBaseCommon<?> getBaseCommonServer() {
        return this.costUnitServer;
    }

    @ApiOperation(value = "分页查询成本单位", notes = "分页成本单位")
    @PostMapping(value = "/findPaginationRO")
    @CheckToken
    public ResponseData<Pagination<CostUnitEntityRO>> findPaginationRO(@RequestBody PaginationRequestData<CostUnitDto> paginationRequestData) {
        Integer pageIndex = paginationRequestData.getPageIndex();
        Integer pageRows = paginationRequestData.getPageRows();
        CostUnitDto costUnitDto = paginationRequestData.getParams();
        JSONObject jsonObject = JSONObject.parseObject(JSONObject.toJSONString(costUnitDto));
        Pagination<CostUnitEntityRO> pagination = costUnitServer.findPaginationRO(jsonObject, pageIndex, pageRows, paginationRequestData.getOrderByBean());
        return ResponseData.data(pagination);
    }

    @ApiOperation(value = "根据id成本单位信息", notes = "根据id成本单位信息")
    @GetMapping(value = "/findById")
    @CheckToken
    public ResponseData<CostUnitEntity> findById(Long id) {
        CostUnitEntity costUnitEntity = costUnitServer.getById(id);
        return ResponseData.data(costUnitEntity);
    }

    @ApiOperation(value = "保存成本单位", notes = "保存成本单位")
    @PostMapping(value = "/save")
    @CheckToken
    public ResponseData<CostUnitEntity> save(@RequestBody RequestData<CostUnitDto> requestData) {
        CostUnitDto costUnitDto = requestData.getParams();
        CostUnitEntity costUnitEntity = JSONObject.parseObject(JSONObject.toJSONString(costUnitDto), CostUnitEntity.class);
        //固定
        costUnitEntity.setOperatorUserId(getUserSessionBean().getUserId());
        costUnitEntity.setTenantId(getUserSessionBean().getTenantId());

        costUnitServer.save(costUnitEntity);
        return ResponseData.data(costUnitEntity);
    }

    @ApiOperation(value = "修改成本单位", notes = "修改成本单位")
    @PostMapping(value = "/update")
    @CheckToken
    public ResponseData<CostUnitEntity> update(@RequestBody RequestData<CostUnitDto> requestData) {
        CostUnitDto costUnitDto = requestData.getParams();
        CostUnitEntity costUnitEntity = costUnitServer.getById(costUnitDto.getCostUnitId());
        if (null != costUnitEntity) {
            BeanUtil.copyProperties(costUnitDto, costUnitEntity);
            //固定
            costUnitEntity.setOperatorUserId(getUserSessionBean().getUserId());
        } else {
            return ResponseData.fail(ResponseMsgCode.UPDATE_DATA_NOT_EXIST.msgCode);
        }
        costUnitServer.update(costUnitEntity);
        return ResponseData.data(costUnitEntity);
    }

    @ApiOperation(value = "通过Id删除成本单位", notes = "通过Id删除成本单位")
    @GetMapping(value = "/delete")
    @CheckToken
    public ResponseData deleteById(@RequestParam Long id) {
        CostUnitEntity costUnitEntity = costUnitServer.getById(id);
        if (costUnitEntity != null) {
            costUnitEntity.setDeleteFlag(1);
            costUnitEntity.setOperatorUserId(getUserSessionBean().getUserId());
        }
        costUnitServer.update(costUnitEntity);
        return ResponseData.success();
    }

    @ApiOperation(value = "批量删除成本单位", notes = "批量删除成本单位")
    @PostMapping(value = "/deleteByIds")
    @CheckToken
    public ResponseData deleteByIds(@RequestBody RequestData<CostUnitDto> requestData) throws ParameterNotValidException {
        CostUnitDto costUnitDto = requestData.getParams();
        if(StrUtil.isEmpty(costUnitDto.getIds())){
            throw new ParameterNotValidException();
        }
        List<String> idList = Arrays.asList(costUnitDto.getIds().split(","));
        for (String id : idList) {
            CostUnitEntity costUnitEntity = costUnitServer.getById(Long.parseLong(id));
            if (costUnitEntity != null) {
                costUnitEntity.setDeleteFlag(1);
                costUnitEntity.setOperatorUserId(getUserSessionBean().getUserId());
            }
            costUnitServer.update(costUnitEntity);
        }
        return ResponseData.success();
    }
}
