package com.yuexiu.secp.read.controller;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson.JSONObject;
import com.sie.iot.common.bean.PaginationRequestData;
import com.sie.iot.common.bean.RequestData;
import com.sie.iot.common.bean.ResponseData;
import com.sie.iot.common.iotenum.ResponseMsgCode;
import com.sie.iot.common.model.inter.IBaseCommon;
import com.sie.iot.common.secure.annotation.CheckToken;
import com.sie.iot.common.services.CommonAbstractService;
import com.siefw.hibernate.core.paging.Pagination;
import com.yuexiu.secp.read.dto.UnitUserDto;
import com.yuexiu.secp.read.model.entities.UnitUserEntity;
import com.yuexiu.secp.read.model.entities.readonly.UnitUserEntityRO;
import com.yuexiu.secp.read.model.service.IUnitUser;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

@Validated
@Api(value = "成本单位授权", tags = "成本单位授权")
@RestController
@RequestMapping("/unitUserController")
public class UnitUserController extends CommonAbstractService {

    @Autowired(required = true)
    private IUnitUser unitUserServer;

    @Override
    public IBaseCommon<?> getBaseCommonServer() {
        return this.unitUserServer;
    }

    @ApiOperation(value = "分页查询成本单位授权", notes = "分页成本单位授权")
    @PostMapping(value = "/findPaginationRO")
    @CheckToken
    public ResponseData<Pagination<UnitUserEntityRO>> findPaginationRO(@RequestBody PaginationRequestData<UnitUserDto> paginationRequestData) {
        Integer pageIndex = paginationRequestData.getPageIndex();
        Integer pageRows = paginationRequestData.getPageRows();
        UnitUserDto unitUserDto = paginationRequestData.getParams();
        JSONObject jsonObject = JSONObject.parseObject(JSONObject.toJSONString(unitUserDto));
        Pagination<UnitUserEntityRO> pagination = unitUserServer.findPaginationRO(jsonObject, pageIndex, pageRows, paginationRequestData.getOrderByBean());
        return ResponseData.data(pagination);
    }

    @ApiOperation(value = "根据id成本单位授权信息", notes = "根据id成本单位授权信息")
    @GetMapping(value = "/findById")
    @CheckToken
    public ResponseData<UnitUserEntity> findById(Long id) {
        UnitUserEntity unitUserEntity = unitUserServer.getById(id);
        return ResponseData.data(unitUserEntity);
    }

    @ApiOperation(value = "保存成本单位授权", notes = "保存成本单位授权")
    @PostMapping(value = "/save")
    @CheckToken
    public ResponseData<UnitUserEntity> save(@RequestBody RequestData<UnitUserDto> requestData) {
        UnitUserDto unitUserDto = requestData.getParams();
        UnitUserEntity unitUserEntity = JSONObject.parseObject(JSONObject.toJSONString(unitUserDto), UnitUserEntity.class);
        //固定
        unitUserEntity.setOperatorUserId(getUserSessionBean().getUserId());
        unitUserEntity.setTenantId(getUserSessionBean().getTenantId());

        unitUserServer.save(unitUserEntity);
        return ResponseData.data(unitUserEntity);
    }

    @PostMapping(value = "/update")
    @CheckToken
    public ResponseData<UnitUserEntity> update(@RequestBody RequestData<UnitUserDto> requestData) {
        UnitUserDto unitUserDto = requestData.getParams();
        UnitUserEntity unitUserEntity = unitUserServer.getById(unitUserDto.getUnitUserId());
        if (null != unitUserEntity) {
            BeanUtil.copyProperties(unitUserDto, unitUserEntity);
            //固定
            unitUserEntity.setOperatorUserId(getUserSessionBean().getUserId());
        } else {
            return ResponseData.fail(ResponseMsgCode.UPDATE_DATA_NOT_EXIST.msgCode);
        }
        unitUserServer.update(unitUserEntity);
        return ResponseData.data(unitUserEntity);
    }

    @ApiOperation(value = "通过Id删除成本单位授权", notes = "通过Id删除成本单位授权")
    @GetMapping(value = "/delete")
    @CheckToken
    public ResponseData deleteById(@RequestParam Long id) {
        UnitUserEntity unitUserEntity = unitUserServer.getById(id);
        if (unitUserEntity != null) {
            unitUserEntity.setDeleteFlag(1);
            unitUserEntity.setOperatorUserId(getUserSessionBean().getUserId());
        }
        unitUserServer.update(unitUserEntity);
        return ResponseData.success();
    }
}
