package com.yuexiu.secp.read.model.service.impl;

import com.itextpdf.text.log.Logger;
import com.itextpdf.text.log.LoggerFactory;
import com.sie.iot.common.model.inter.server.BaseCommonServer;
import com.yuexiu.secp.read.dto.ArticleAddCountDto;
import com.yuexiu.secp.read.infra.constant.ArticleConstant;
import com.yuexiu.secp.read.infra.util.RedisUtils;
import com.yuexiu.secp.read.model.entities.ArticleGatherEntity;
import com.yuexiu.secp.read.model.service.IArticleGatherServer;
import com.yuexiu.secp.read.vo.StatisticsRespVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

@Service
public class ArticleGatherServer extends BaseCommonServer<ArticleGatherEntity> implements IArticleGatherServer {

    private static final Logger LOGGER = LoggerFactory.getLogger(ArticleGatherServer.class);

    //阅读标记
    public final static Integer READ_TYPE = 1;

    //阅读标记
    public final static Integer SHARE_TYPE = 2;


    /**
     * redis
     */
    @Autowired
    private StringRedisTemplate redisTemplate;


    /**
     * 获取文章统计数
     * type：
     * 1：阅读数
     * 2：转发数
     *
     * @param articleId
     */
    public String findByArticleIdAndTypeCount(Long articleId, int type) {
        LOGGER.info("articleId : {}" + articleId + "type --> {}" + type);
        String count = "";
        if (type == READ_TYPE) {
            count = redisTemplate.opsForValue().get(RedisUtils.getRedisKey(ArticleConstant.SIE, ArticleConstant.READ, String.valueOf(articleId)));
        } else if (type == SHARE_TYPE) {
            count = redisTemplate.opsForValue().get(RedisUtils.getRedisKey(ArticleConstant.SIE, ArticleConstant.SHARE, String.valueOf(articleId)));
        }
        return count;
    }

    /**
     * 根据文章id获取相关统计数
     *
     * @param articleId
     */
    @Override
    public StatisticsRespVo findByArticleIdCount(Long articleId) {
        LOGGER.info("articleId : {}" + articleId);

        StatisticsRespVo statisticsRespVo = new StatisticsRespVo();
        //获取阅读数
        String read = this.findByArticleIdAndTypeCount(articleId, READ_TYPE);
        String share = this.findByArticleIdAndTypeCount(articleId, SHARE_TYPE);
        LOGGER.info("该文章id：" + articleId + "获取到的阅读数：" + read + "和分享数:" + share);
        //组装数据
        statisticsRespVo.setRead(!StringUtils.isEmpty(read) ? read : "0");
        statisticsRespVo.setShare(!StringUtils.isEmpty(share) ? read : "0");

        return statisticsRespVo;

    }


    /**
     * 根据文章和类型，增加相关的统计数
     *
     * @param articlePreviewDto
     */
    @Override
    public void addArticleCount(ArticleAddCountDto articlePreviewDto) {
        LOGGER.info("articlePreviewDto : {}" + articlePreviewDto);
        if (articlePreviewDto.getType() == READ_TYPE) {
            redisTemplate.opsForValue().increment(RedisUtils.getRedisKey(ArticleConstant.SIE, ArticleConstant.READ, articlePreviewDto.getArticleId()), 1L);
        } else if (articlePreviewDto.getType() == SHARE_TYPE) {
            redisTemplate.opsForValue().increment(RedisUtils.getRedisKey(ArticleConstant.SIE, ArticleConstant.SHARE, articlePreviewDto.getArticleId()), 1L);
        } else {
            LOGGER.error("传参有误，没有定义该类型：" + articlePreviewDto.getType());
        }
    }


}
