package com.yuexiu.secp.read.model.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.sie.iot.common.bean.OrderByBean;
import com.sie.iot.common.model.inter.server.BaseCommonServer;
import com.sie.iot.common.util.SaafToolUtils;
import com.sie.iot.common.util.UserSessionHelper;
import com.siefw.hibernate.core.paging.Pagination;
import com.yuexiu.secp.read.model.dao.ArticlePreviewContentDao;
import com.yuexiu.secp.read.model.dao.ArticlePreviewDao;
import com.yuexiu.secp.read.dto.ArticlePreviewSaveDto;
import com.yuexiu.secp.read.model.entities.ArticlePreviewContentEntity;
import com.yuexiu.secp.read.model.entities.ArticlePreviewEntity;
import com.yuexiu.secp.read.model.service.IArticlePreview;
import com.yuexiu.secp.read.model.service.IArticlePreviewContent;
import com.yuexiu.secp.read.util.DateUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.time.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @author YuChengLong
 * @date 2022/5/10
 */
@Slf4j
@Service
public class ArticlePreviewServer extends BaseCommonServer<ArticlePreviewEntity> implements IArticlePreview {

    @Autowired
    private StringRedisTemplate redisTemplate;

    @Autowired
    private ArticlePreviewDao articlePreviewDao;

    @Autowired
    private ArticlePreviewContentDao articlePreviewContentDao;

    @Override
    public ArticlePreviewEntity saveArticlePreview(ArticlePreviewSaveDto dto) {

        // TODO 需要加事务
        ArticlePreviewEntity entity = new ArticlePreviewEntity();
        BeanUtil.copyProperties(dto, entity);
        //固定
        entity.setOperatorUserId(1L);
        entity.setTenantId(1L);
//        entity.setOperatorUserId(UserSessionHelper.getCurrentSession().getUserId());
//        entity.setTenantId(UserSessionHelper.getCurrentSession().getTenantId());
        // 推广状态
        Date now = new Date();
        if (DateUtil.str2Time(dto.getSpreadBeginTime()).getTime() > now.getTime()) {
            entity.setPromotionStatus(3);
        } else if (DateUtil.str2Time(dto.getSpreadEndTime()).getTime() < now.getTime()) {
            entity.setPromotionStatus(2);
        } else if (DateUtil.str2Time(dto.getSpreadEndTime()).getTime() > now.getTime() && DateUtil.str2Time(dto.getSpreadBeginTime()).getTime() <= now.getTime()) {
            entity.setPromotionStatus(1);
        }
        // 审批状态
        entity.setApprovalStatus(1);

        // 保存预览记录
        entity = (ArticlePreviewEntity) this.save(entity);

        long articlePreviewId = entity.getArticlePreviewId();
        // 保存文章正文详情
        ArticlePreviewContentEntity contentEntity = new ArticlePreviewContentEntity();
        //固定
        contentEntity.setOperatorUserId(1L);
        contentEntity.setTenantId(1L);
        contentEntity.setArticlePreviewId(articlePreviewId);
        contentEntity.setArticleContent(dto.getArticleContent());

        articlePreviewContentDao.save(contentEntity);

        // 关联类型
//        int placeOfOrigin = dto.getPlaceOfOrigin();
        // TODO 根据类型去CDP查询相关信息，将得到的结果存入yxh_article_preview_project表中

        // 推广人
        // TODO 同上，需要去CDP查询相关信息

        return entity;
    }

    @Override
    public ArticlePreviewEntity updateArticlePreview(ArticlePreviewSaveDto dto) {

        // TODO 需要加事务
        ArticlePreviewEntity entity = new ArticlePreviewEntity();
        BeanUtil.copyProperties(dto, entity);
        //固定
        entity.setOperatorUserId(1L);
        entity.setTenantId(1L);
//        entity.setOperatorUserId(UserSessionHelper.getCurrentSession().getUserId());
//        entity.setTenantId(UserSessionHelper.getCurrentSession().getTenantId());
        // 推广状态
        Date now = new Date();
        if (DateUtil.str2Time(dto.getSpreadBeginTime()).getTime() > now.getTime()) {
            entity.setPromotionStatus(3);
        } else if (DateUtil.str2Time(dto.getSpreadEndTime()).getTime() < now.getTime()) {
            entity.setPromotionStatus(2);
        } else if (DateUtil.str2Time(dto.getSpreadEndTime()).getTime() > now.getTime() && DateUtil.str2Time(dto.getSpreadBeginTime()).getTime() <= now.getTime()) {
            entity.setPromotionStatus(1);
        }
        // 审批状态
        entity.setApprovalStatus(1);

        // 更新预览记录
        this.update(entity);

        long articlePreviewId = entity.getArticlePreviewId();
        // 保存文章正文详情
        ArticlePreviewContentEntity contentEntity = new ArticlePreviewContentEntity();
        //固定
        contentEntity.setOperatorUserId(1L);
        contentEntity.setTenantId(1L);
        contentEntity.setArticlePreviewId(articlePreviewId);
        contentEntity.setArticleContent(dto.getArticleContent());

        ArticlePreviewContentEntity articlePreviewContentEntity =
                articlePreviewContentDao.selectByArticlePreviewId(articlePreviewId);
        contentEntity.setPreviewContentId(articlePreviewContentEntity.getPreviewContentId());
        articlePreviewContentDao.update(contentEntity);

        // 关联类型
//        int placeOfOrigin = dto.getPlaceOfOrigin();
        // TODO 根据类型去CDP查询相关信息，将得到的结果存入yxh_article_preview_project表中

        // 推广人
        // TODO 同上，需要去CDP查询相关信息

        return entity;
    }

    @Override
    public ArticlePreviewSaveDto findByArticlePreviewId(Long previewId) {

        ArticlePreviewSaveDto saveDto = new ArticlePreviewSaveDto();
        // 查询文章预览基本信息
        ArticlePreviewEntity articlePreviewEntity = articlePreviewDao.getById(previewId);
        BeanUtil.copyProperties(articlePreviewEntity, saveDto);
        // 查询文章正文内容
        ArticlePreviewContentEntity articlePreviewContentEntity =
                articlePreviewContentDao.selectByArticlePreviewId(previewId);
        saveDto.setArticleContent(articlePreviewContentEntity.getArticleContent());
        // TODO 查询文章推广人信息

        // TODO 查询文章所属城市/项目
        return saveDto;
    }

    @Override
    public Pagination<ArticlePreviewEntity> findPagination(JSONObject jsonObject, Integer pageIndex, Integer pageRows, OrderByBean orderByBean) {
        Map<String, Object> paramsMap = new HashMap<String, Object>();
        StringBuffer querySQLSB = new StringBuffer("select * from yxh_article_preview where delete_flag = 0 ");

        //通过标题查询
        if (StrUtil.isNotEmpty(jsonObject.getString("articleTitle"))) {
            SaafToolUtils.parperParam(jsonObject, "article_title", "articleTitle", querySQLSB, paramsMap, "like");
        }

        //通过发布单位查询
        if (StrUtil.isNotEmpty(jsonObject.getString("publishUnit"))) {
            SaafToolUtils.parperParam(jsonObject, "publish_unit", "publishUnit", querySQLSB, paramsMap, "like");
        }

        //通过推广状态查询
        if (jsonObject.getLong("promotionStatus") != null) {
            SaafToolUtils.parperParam(jsonObject, "promotion_status", "promotionStatus", querySQLSB, paramsMap, "=");
        }

        //通过任务状态查询
        if (jsonObject.getLong("taskStatus") != null) {
            SaafToolUtils.parperParam(jsonObject, "task_status", "taskStatus", querySQLSB, paramsMap, "=");
        }

        //通过操作人查询
        if (StrUtil.isNotEmpty(jsonObject.getString("oprator"))) {
            // TODO 需要根据用户名查出userId,再去查询created_by
            SaafToolUtils.parperParam(jsonObject, "created_by", "oprator", querySQLSB, paramsMap, "like");
        }

        //通过推广有效期查询
        if (!StrUtil.isBlank(jsonObject.getString("spreadBeginTime"))) {
            querySQLSB.append(" and ((spread_begin_time between :spreadBeginTime and :spreadEndTime) or " +
                    "(spread_end_time between :spreadBeginTime and :spreadEndTime) or " +
                    "(spread_begin_time <= :spreadBeginTime and spread_end_time >= :spreadEndTime))");
            paramsMap.put("spreadBeginTime", jsonObject.getDate("spreadBeginTime"));
            paramsMap.put("spreadEndTime", jsonObject.getDate("spreadEndTime"));
            paramsMap.put("spreadBeginTime", jsonObject.getDate("spreadBeginTime"));
            paramsMap.put("spreadEndTime", jsonObject.getDate("spreadEndTime"));
            paramsMap.put("spreadBeginTime", jsonObject.getDate("spreadBeginTime"));
            paramsMap.put("spreadEndTime", jsonObject.getDate("spreadEndTime"));
        }

        // 通过计划发布时间查询
        if (!StrUtil.isBlank(jsonObject.getString("releaseBeginTime"))) {
            paramsMap.put("releaseBeginTime", jsonObject.getDate("releaseBeginTime"));
            querySQLSB.append(" and release_time >= :releaseBeginTime ");
        }
        if (!StrUtil.isBlank(jsonObject.getString("releaseEndTime"))) {
            paramsMap.put("releaseEndTime", jsonObject.getDate("releaseEndTime"));
            querySQLSB.append(" and release_time <= :releaseEndTime ");
        }

        // 通过实际发布时间查询
        if (!StrUtil.isBlank(jsonObject.getString("releaseTaskBeginTime"))) {
            paramsMap.put("releaseTaskBeginTime", jsonObject.getDate("releaseTaskBeginTime"));
            querySQLSB.append(" and release_task_time >= :releaseTaskBeginTime ");
        }
        if (!StrUtil.isBlank(jsonObject.getString("releaseTaskEndTime"))) {
            paramsMap.put("releaseTaskEndTime", jsonObject.getDate("releaseTaskEndTime"));
            querySQLSB.append(" and release_task_time <= :releaseTaskEndTime ");
        }

        if (orderByBean == null) {
            orderByBean = new OrderByBean();
            orderByBean.setAttributeName("creation_date");
            orderByBean.setSortType("desc");
        }

        SaafToolUtils.sortUtil(orderByBean, querySQLSB);
        return articlePreviewDao.findPagination(querySQLSB.toString(), paramsMap, pageIndex, pageRows);
    }

}
