package com.yuexiu.secp.read.model.service.impl;


import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.common.collect.Iterables;
import com.yuexiu.secp.read.dto.ArticleQueryDto;
import com.yuexiu.secp.read.infra.constant.ArticleConstant;
import com.yuexiu.secp.read.infra.util.RedisUtils;
import com.yuexiu.secp.read.model.dao.ArticleDao;
import com.yuexiu.secp.read.model.entities.ArticleEntity;

import com.yuexiu.secp.read.model.service.IArticleServer;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.*;

/**
 * @author YuChengLong
 * @date 2022/5/10
 */

@Service
public class ArticleServer implements IArticleServer{


    /**
     * redis
     */
    @Autowired
    private StringRedisTemplate redisTemplate;

    /**
     * 文章DAO
     */
    @Autowired
    private ArticleDao articleDao;


    /**
     * 最新推荐
     * @param articleQueryDto
     * @return
     */
    @Override
    public List<ArticleEntity> findNewest(ArticleQueryDto articleQueryDto) {
        //项目的集合信息
        List<ArticleEntity> projectList = new ArrayList<>();

        //城市的集合信息
        List<ArticleEntity> articlePreviewList = new ArrayList<>();

        List<ArticleEntity> dataList = new ArrayList<>();

        //查询是否有最新推荐
        int count = articleDao.findRecommend();
        if (count < 1) {
            return null;
        }
        //获取当前登录用户

        //获取我已推荐的文章
        Set<String> recommendIdList = redisTemplate.opsForSet().members(RedisUtils.getRedisKey(ArticleConstant.SIE , ArticleConstant.RECOMMEND ,String.valueOf(articleQueryDto.getUserId())));
        //获取所有文章的信息
        Map<Object, Object> entries = redisTemplate.opsForHash().entries(RedisUtils.getRedisKey(ArticleConstant.SIE , ArticleConstant.READ ,ArticleConstant.ARTICLE));
        ObjectMapper objectMapper = new ObjectMapper();
        //剔除我已推荐文章
        for (String recommendId : recommendIdList) {
            entries.remove(recommendId);
        }
        Collection<Object> values = entries.values();

        //判断是否有房产
        //todo 调用第三方接口cdp，查询是否有房产
        if (true) {
            for (Object value : values) {
                //匹配项目，任务状态为已发布 ， 推广状态为有效
                ArticleEntity articlePreview = objectMapper.convertValue(value,ArticleEntity.class);
                if(articlePreview.getPromotionStatus() == articleQueryDto.getPromotionStatus() &&
                        articlePreview.getTaskStatus() == articleQueryDto.getTaskStatus()){
                    //往城市里的集合塞数据
                    projectList.add(articlePreview);
                }
                System.out.println(value);
            }
        }


        for (Object value : values) {
            //匹配城市，任务状态为已发布 ， 推广状态为有效
            ArticleEntity articlePreview = objectMapper.convertValue(value,ArticleEntity.class);
            if(articlePreview.getPromotionStatus() == articleQueryDto.getPromotionStatus() &&
                    articlePreview.getTaskStatus() == articleQueryDto.getTaskStatus()){
                //往城市里的集合塞数据
                articlePreviewList.add(articlePreview);
            }
            System.out.println(value);
        }

        //如果项目类型不为空，合并项目和城市
        if(!CollectionUtils.isEmpty(projectList)){
            Iterables.addAll(dataList, projectList);
            Iterables.addAll(dataList, articlePreviewList);
        }

        return dataList;
    }

    /**
     * 往期推荐
     * @param articleQueryDto
     * @return
     */
    @Override
    public List<ArticleEntity> findPrevious(ArticleQueryDto articleQueryDto) {
        return null;
    }



}
