package com.yuexiu.secp.read.util;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @author YuChengLong
 * @date 2022/5/10
 */
public class DateUtil {

    public static final String DATE_FORMAT_YY_MM_DD = "yyyy-MM-dd";

    public static final String DATE_FORMAT_YY_MM_DD_HH_MM_SS = "yyyy-MM-dd HH:mm:ss";

    private static SimpleDateFormat sdf_date_format = new SimpleDateFormat(DATE_FORMAT_YY_MM_DD);
    private static SimpleDateFormat sdf_time_format = new SimpleDateFormat(DATE_FORMAT_YY_MM_DD_HH_MM_SS);

    /**
     * java 获取月周
     */
    public static Integer getDateOfWeek(String data) {
        Calendar calendar = Calendar.getInstance();
        calendar.setFirstDayOfWeek(Calendar.SUNDAY);// 设置星期一为一周开始的第一天
        // calendar.setMinimalDaysInFirstWeek(4);//可以不用设置
        calendar.setTime(DateUtil.str2Date(data));// 获得当前的时间戳
        return calendar.get(Calendar.WEEK_OF_YEAR);
    }

    /**
     * 获取当前日期的上一个月
     */
    public static Date getLastMonth(Date date) {
        Calendar c = Calendar.getInstance();
        c.setTime(date);
        c.add(Calendar.MONTH, -1);
        return c.getTime();
    }

    /**
     * 获取当前日期的下一个月的日期(下个月日期不能超过2月29)
     *
     * @param date 输入日期
     * @return
     */
    public static Date getNextMonth(Date date) {
        Calendar c = Calendar.getInstance();
        c.setTime(new Date());
        c.add(Calendar.MONTH, -1);
        return c.getTime();
    }

    /**
     * 获取当前日期是当年的第几周
     *
     * @param date 日期
     * @return
     */
    public static Integer getWeekOfYear(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setFirstDayOfWeek(Calendar.SUNDAY);
        calendar.setTime(date);
        return calendar.get(Calendar.WEEK_OF_YEAR);
    }

    /**
     * 根据日期获取该天星期几
     *
     * @param date 日期
     * @return
     */
    public static String getWeek(Date date) {
        String[] weeks = {"星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六"};
        Calendar cal = Calendar.getInstance();
        cal.setTime(date);
        int week_index = cal.get(Calendar.DAY_OF_WEEK) - 1;
        if (week_index < 0) {
            week_index = 0;
        }
        return weeks[week_index];
    }

    /**
     * 根据输入日期获取今天是周几(数值: 1 2 3 4 5 6 7)
     *
     * @param date 输入日期
     * @return 周几(数值)
     */
    public static int getWeek1(Date date) {
        int[] weeks = {7, 1, 2, 3, 4, 5, 6};
        Calendar cal = Calendar.getInstance();
        cal.setTime(date);
        int week_index = cal.get(Calendar.DAY_OF_WEEK) - 1;
        if (week_index < 0) {
            week_index = 0;
        }
        return weeks[week_index];
    }

    /**
     * 获取指定日期的过去第past天的日期
     */
    public static Date getPastDate(Date date, int past) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.add(Calendar.DATE, -past);
        return calendar.getTime();
    }

    /**
     * 获取指定日期的之后第past天的日期
     */
    public static Date getLaterDate(Date date, int past) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.add(Calendar.DATE, past);
        return calendar.getTime();
    }

    /**
     * 获取指定日期的字符串之后第past天的日期字符串
     */
    public static String getLaterDateStr(String date, int past) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(str2Date(date));
        calendar.add(Calendar.DATE, past);
        return date2Str(calendar.getTime());
    }

    /**
     * 给时间加上几个小时
     *
     * @param hour 需要加的时间
     * @return
     */
    public static Date dateAddHours(Date date, int hour) {
        Calendar cal = Calendar.getInstance();
        cal.setTime(date);
        cal.add(Calendar.HOUR, hour);// 24小时制
        date = cal.getTime();
        return date;

    }

    /**
     * 字符串格式转换time
     *
     * @param date
     * @return
     */
    public static Date str2Time(String date) {
        Date result = null;
        try {
            result = sdf_time_format.parse(date);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return result;
    }

    /**
     * 字符串格式转换date
     *
     * @param date
     * @return
     */
    public static Date str2Date(String date) {
        Date result = null;
        try {
            result = sdf_date_format.parse(date);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return result;
    }

    /**
     * date转换字符串格式
     *
     * @param date
     * @return
     */
    public static String date2Str(Date date) {
        String dateString = sdf_date_format.format(date);
        return dateString;
    }

    /**
     * 计算两个日期之间相隔的天数
     *
     * @param begin
     * @param end
     * @return
     * @throws ParseException
     */
    public static long countDay(String begin, String end) {
        Date beginDate, endDate;
        long day = 0;
        try {
            beginDate = sdf_date_format.parse(begin);
            endDate = sdf_date_format.parse(end);
            day = (endDate.getTime() - beginDate.getTime()) / (24 * 60 * 60 * 1000);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return day;
    }

    public static int getMonth(String date) {
        Calendar c = Calendar.getInstance();
        c.setTime(str2Date(date));
        return c.get(Calendar.MONTH) + 1;
    }

    public static int getYear(String date) {
        Calendar c = Calendar.getInstance();
        c.setTime(str2Date(date));
        return c.get(Calendar.YEAR);
    }

    public static void main(String[] args) {

    }

}
